package com.nisum.banderson;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.openqa.selenium.By;
import org.openqa.selenium.Platform;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.remote.RemoteWebDriver;
import org.openqa.selenium.safari.SafariDriver;
import org.openqa.selenium.support.PageFactory;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import java.util.concurrent.TimeUnit;

public class Test {
    private static WebDriver driver;
    private static String url;


    @BeforeEach
    public void setUp() {
        url = "http://www.albertsons.com";
        switch (PropertyManager.getInstance().getBrowser()) {
            case "chrome":
                driver = new ChromeDriver();
                break;

            case "safari":
                driver = new SafariDriver();
                break;
        }

        driver.manage().timeouts().implicitlyWait(3000, TimeUnit.MILLISECONDS);
        Platform platform = ((RemoteWebDriver) driver).getCapabilities().getPlatform();
        System.out.printf(
                "Running WebDriver on %s browser running on %s platform...", PropertyManager.getInstance().getBrowser(), platform
        );
        driver.manage().window().fullscreen();
        driver.navigate().to(url);
    }

    @AfterEach
    public void tearDown() {
        driver.close();
    }


    @org.junit.jupiter.api.Test
    public void login() throws Exception {
        Header header = new Header(driver);
        Sidebar sidebar = new Sidebar(driver);
        Login login = new Login(driver);
        PageFactory.initElements(driver, sidebar);

        header.getOpenSidebarButton().click();
        sidebar.openModalButton.click();
        login.getEmailInput().sendKeys(PropertyManager.getInstance().getEmail());
        login.getPasswordInput().sendKeys(PropertyManager.getInstance().getPassword());
        login.getSignInButton().click();
        new WebDriverWait(driver, 20)
                .until(ExpectedConditions.textToBe(
                        By.className("menu-nav__profile-button-sign-in-up"),
                        "Account"
                ));
        Assertions.assertEquals("Account", header.getOpenSidebarButton().getText());
    }


    @org.junit.jupiter.api.Test
    public void testNavigation() {
        Header header = new Header(driver);
        Sidebar sidebar = new Sidebar(driver);
        PageFactory.initElements(sidebar.getDriver(), sidebar);

        header.getOpenSidebarButton().click();
        sidebar.accountButton.click();
        Assertions.assertEquals("Account Settings | albertsons", driver.getTitle());
    }

}
